package jdk.javadoc.internal.tool.resources;

public final class version extends java.util.ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "full", "18.0.1.1+2" },
            { "jdk", "18.0.1.1" },
            { "release", "18.0.1.1" },
        };
    }
}
